@@ -2,8 +2,10 @@ import functools
 import json
 import re
 import typing as t
-from collections import OrderedDict
+from concurrent.futures import ThreadPoolExecutor
+from urllib import parse
 
+from anyio._backends._asyncio import get_running_loop
 from fastapi import APIRouter, HTTPException, Request, Response, status
 from fastapi.staticfiles import StaticFiles
 from starlette.middleware.base import BaseHTTPMiddleware, RequestResponseEndpoint
@@ -48,6 +50,8 @@ class DebugToolbarMiddleware(BaseHTTPMiddleware):
             StaticFiles(packages=[__package__]),
             name="debug_toolbar.static",
         )
+        loop = get_running_loop()
+        loop.set_default_executor(ThreadPoolExecutor(max_workers=1))
 
     async def dispatch(
         self,
@@ -76,29 +80,28 @@ class DebugToolbarMiddleware(BaseHTTPMiddleware):
         await toolbar.record_server_timing(response)
         toolbar.generate_server_timing_header(response)
 
-        async for body in response.body_iterator:  # type: ignore
-            if not isinstance(body, bytes):
-                body = body.encode(response.charset)
-
-        decoded = body.decode(response.charset)
-
         if is_html:
+            async for body in response.body_iterator:  # type: ignore
+                if not isinstance(body, bytes):
+                    body = body.encode(response.charset)
+
+            decoded = body.decode(response.charset)
             pattern = re.escape(self.settings.INSERT_BEFORE)
             bits = re.split(pattern, decoded, flags=re.IGNORECASE)
 
             if len(bits) > 1:
                 bits[-2] += toolbar.render_toolbar()
                 body = self.settings.INSERT_BEFORE.join(bits).encode(response.charset)
+                response.headers["Content-Length"] = str(len(body))
+
+            async def stream() -> t.AsyncGenerator[bytes, None]:
+                yield body
+
+            response.body_iterator = stream()  # type: ignore
         else:
-            data = json.loads(decoded, object_pairs_hook=OrderedDict)
-            data["debugToolbar"] = toolbar.refresh()
-            body = json.dumps(data).encode(response.charset)
+            data = parse.quote(json.dumps(toolbar.refresh()))
+            response.set_cookie(key="dtRefresh", value=data)
 
-        async def stream() -> t.AsyncGenerator[bytes, None]:
-            yield body
-
-        response.body_iterator = stream()  # type: ignore
-        response.headers["Content-Length"] = str(len(body))
         return response
 
     def require_show_toolbar(
