@@ -3,6 +3,7 @@ import typing as t
 from fastapi import Request, Response
 
 from debug_toolbar.panels import Panel
+from debug_toolbar.types import Stats
 from debug_toolbar.utils import get_name_from_obj
 
 
@@ -14,11 +15,7 @@ class RequestPanel(Panel):
     def nav_subtitle(self) -> str:
         return get_name_from_obj(self.endpoint)
 
-    async def generate_stats(
-        self,
-        request: Request,
-        response: Response,
-    ) -> t.Optional[t.Dict[str, t.Any]]:
+    async def generate_stats(self, request: Request, response: Response) -> Stats:
         self.endpoint = request.scope["endpoint"]
         stats: t.Dict[str, t.Any] = {"request": request}
 
